@@ -3,10 +3,8 @@ use criterion::{criterion_group, criterion_main};
 use sys_metrics::network::*;
 
 pub fn network_benches(c: &mut Criterion) {
-    c.bench_function("get_net_iocounters", |b| b.iter(|| get_net_iocounters()));
-    c.bench_function("get_net_physical_iocounters", |b| {
-        b.iter(|| get_net_physical_iocounters())
-    });
+    c.bench_function("get_ionets", |b| b.iter(|| get_ionets()));
+    c.bench_function("get_physical_ionets", |b| b.iter(|| get_physical_ionets()));
 }
 
 criterion_group!(benches, network_benches);
