@@ -1,4 +1,4 @@
-use sys_metrics::{cpu::*, disks::*, host::*, memory::*, network::*};
+use sys_metrics::{cpu::*, disks::*, host::*, memory::*, network::*, virt::*};
 
 #[allow(unused_must_use)]
 fn main() {
@@ -7,7 +7,7 @@ fn main() {
     dbg!(get_cpustats());
     dbg!(get_cputimes());
     dbg!(get_loadavg());
-    dbg!(get_iostats_physical());
+    dbg!(get_physical_ioblocks());
     dbg!(get_partitions_physical());
     dbg!(get_host_info());
     dbg!(get_hostname());
@@ -18,5 +18,6 @@ fn main() {
     dbg!(get_memory());
     dbg!(get_swap());
     dbg!(has_swap());
-    dbg!(get_net_physical_iocounters());
+    dbg!(get_physical_ionets());
+    dbg!(get_virt_info());
 }
