@@ -3,10 +3,10 @@ use std::io::Error;
 /// Return the number of logical core the system has.
 ///
 /// On linux it will gather the info from libc's sysconf or sched_getaffinity as a fallback.
-pub fn get_cpu_logical_count() -> Result<i64, Error> {
+pub fn get_cpu_logical_count() -> Result<u32, Error> {
     let cpus = unsafe { libc::sysconf(libc::_SC_NPROCESSORS_ONLN) };
     if cpus >= 0 {
-        return Ok(cpus);
+        return Ok(cpus as u32);
     }
     let mut set = std::mem::MaybeUninit::<libc::cpu_set_t>::uninit();
     if unsafe {
@@ -19,7 +19,7 @@ pub fn get_cpu_logical_count() -> Result<i64, Error> {
                 count += 1
             }
         }
-        Ok(count.into())
+        Ok(count)
     } else {
         Err(Error::last_os_error())
     }
