@@ -4,6 +4,7 @@ mod users;
 mod uuid;
 
 pub use host_info::*;
-pub use sysinfo::*;
 pub use users::*;
 pub use uuid::*;
+
+pub(crate) use sysinfo::*;
