@@ -9,14 +9,14 @@
 //!
 //! ## Quick start
 //! ```
-//! use sys_metrics::{cpu::*, disks::*, host::*, memory::*, network::*};
+//! use sys_metrics::{cpu::*, disks::*, host::*, memory::*, network::*, virt::*};
 //!
 //! dbg!(get_cpu_logical_count());
 //! dbg!(get_cpufreq());
 //! dbg!(get_cpustats());
 //! dbg!(get_cputimes());
 //! dbg!(get_loadavg());
-//! dbg!(get_iostats_physical());
+//! dbg!(get_physical_ioblocks());
 //! dbg!(get_partitions_physical());
 //! dbg!(get_host_info());
 //! dbg!(get_hostname());
@@ -27,7 +27,8 @@
 //! dbg!(get_memory());
 //! dbg!(get_swap());
 //! dbg!(has_swap());
-//! dbg!(get_net_physical_iocounters());
+//! dbg!(get_physical_ionets());
+//! dbg!(get_virt_info());
 //! ```
 
 /// CPU information
@@ -40,6 +41,8 @@ pub mod host;
 pub mod memory;
 /// Network information
 pub mod network;
+/// Virtualization information
+pub mod virt;
 
 #[cfg(target_os = "macos")]
 pub mod macos_binding;
